==> certmanager-model-v1alpha2-6.3.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01FluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01FluentImpl<A extends ACMEChallengeSolverHTTP01Fluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01Fluent<A>{
  public ACMEChallengeSolverHTTP01FluentImpl() {
  }
  public ACMEChallengeSolverHTTP01FluentImpl(ACMEChallengeSolverHTTP01 instance) {
    this.withGatewayHTTPRoute(instance.getGatewayHTTPRoute()); 
    this.withIngress(instance.getIngress()); 
  }
  private ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder gatewayHTTPRoute;
  private ACMEChallengeSolverHTTP01IngressBuilder ingress;
  
  /**
   * This method has been deprecated, please use method buildGatewayHTTPRoute instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01GatewayHTTPRoute getGatewayHTTPRoute() {
    return this.gatewayHTTPRoute!=null ?this.gatewayHTTPRoute.build():null;
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRoute buildGatewayHTTPRoute() {
    return this.gatewayHTTPRoute!=null ?this.gatewayHTTPRoute.build():null;
  }
  public A withGatewayHTTPRoute(ACMEChallengeSolverHTTP01GatewayHTTPRoute gatewayHTTPRoute) {
    _visitables.get("gatewayHTTPRoute").remove(this.gatewayHTTPRoute);
    if (gatewayHTTPRoute!=null){ this.gatewayHTTPRoute= new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(gatewayHTTPRoute); _visitables.get("gatewayHTTPRoute").add(this.gatewayHTTPRoute);} else { this.gatewayHTTPRoute = null; _visitables.get("gatewayHTTPRoute").remove(this.gatewayHTTPRoute); } return (A) this;
  }
  public Boolean hasGatewayHTTPRoute() {
    return this.gatewayHTTPRoute != null;
  }
  public ACMEChallengeSolverHTTP01Fluent.GatewayHTTPRouteNested<A> withNewGatewayHTTPRoute() {
    return new ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNestedImpl();
  }
  public ACMEChallengeSolverHTTP01Fluent.GatewayHTTPRouteNested<A> withNewGatewayHTTPRouteLike(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
    return new ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01Fluent.GatewayHTTPRouteNested<A> editGatewayHTTPRoute() {
    return withNewGatewayHTTPRouteLike(getGatewayHTTPRoute());
  }
  public ACMEChallengeSolverHTTP01Fluent.GatewayHTTPRouteNested<A> editOrNewGatewayHTTPRoute() {
    return withNewGatewayHTTPRouteLike(getGatewayHTTPRoute() != null ? getGatewayHTTPRoute(): new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder().build());
  }
  public ACMEChallengeSolverHTTP01Fluent.GatewayHTTPRouteNested<A> editOrNewGatewayHTTPRouteLike(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
    return withNewGatewayHTTPRouteLike(getGatewayHTTPRoute() != null ? getGatewayHTTPRoute(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01Ingress getIngress() {
    return this.ingress!=null ?this.ingress.build():null;
  }
  public ACMEChallengeSolverHTTP01Ingress buildIngress() {
    return this.ingress!=null ?this.ingress.build():null;
  }
  public A withIngress(ACMEChallengeSolverHTTP01Ingress ingress) {
    _visitables.get("ingress").remove(this.ingress);
    if (ingress!=null){ this.ingress= new ACMEChallengeSolverHTTP01IngressBuilder(ingress); _visitables.get("ingress").add(this.ingress);} else { this.ingress = null; _visitables.get("ingress").remove(this.ingress); } return (A) this;
  }
  public Boolean hasIngress() {
    return this.ingress != null;
  }
  public ACMEChallengeSolverHTTP01Fluent.IngressNested<A> withNewIngress() {
    return new ACMEChallengeSolverHTTP01FluentImpl.IngressNestedImpl();
  }
  public ACMEChallengeSolverHTTP01Fluent.IngressNested<A> withNewIngressLike(ACMEChallengeSolverHTTP01Ingress item) {
    return new ACMEChallengeSolverHTTP01FluentImpl.IngressNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01Fluent.IngressNested<A> editIngress() {
    return withNewIngressLike(getIngress());
  }
  public ACMEChallengeSolverHTTP01Fluent.IngressNested<A> editOrNewIngress() {
    return withNewIngressLike(getIngress() != null ? getIngress(): new ACMEChallengeSolverHTTP01IngressBuilder().build());
  }
  public ACMEChallengeSolverHTTP01Fluent.IngressNested<A> editOrNewIngressLike(ACMEChallengeSolverHTTP01Ingress item) {
    return withNewIngressLike(getIngress() != null ? getIngress(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEChallengeSolverHTTP01FluentImpl that = (ACMEChallengeSolverHTTP01FluentImpl) o;
    if (gatewayHTTPRoute != null ? !gatewayHTTPRoute.equals(that.gatewayHTTPRoute) :that.gatewayHTTPRoute != null) return false;
    if (ingress != null ? !ingress.equals(that.ingress) :that.ingress != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(gatewayHTTPRoute,  ingress,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (gatewayHTTPRoute != null) { sb.append("gatewayHTTPRoute:"); sb.append(gatewayHTTPRoute + ","); }
    if (ingress != null) { sb.append("ingress:"); sb.append(ingress); }
    sb.append("}");
    return sb.toString();
  }
  class GatewayHTTPRouteNestedImpl<N> extends ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl<ACMEChallengeSolverHTTP01Fluent.GatewayHTTPRouteNested<N>> implements ACMEChallengeSolverHTTP01Fluent.GatewayHTTPRouteNested<N>,Nested<N>{
    GatewayHTTPRouteNestedImpl(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
      this.builder = new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(this, item);
    }
    GatewayHTTPRouteNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(this);
    }
    ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01FluentImpl.this.withGatewayHTTPRoute(builder.build());
    }
    public N endGatewayHTTPRoute() {
      return and();
    }
    
  }
  class IngressNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressFluentImpl<ACMEChallengeSolverHTTP01Fluent.IngressNested<N>> implements ACMEChallengeSolverHTTP01Fluent.IngressNested<N>,Nested<N>{
    IngressNestedImpl(ACMEChallengeSolverHTTP01Ingress item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressBuilder(this, item);
    }
    IngressNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01FluentImpl.this.withIngress(builder.build());
    }
    public N endIngress() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01FluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01FluentImpl<A extends ACMEChallengeSolverHTTP01Fluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01Fluent<A>{
  public ACMEChallengeSolverHTTP01FluentImpl() {
  }
  public ACMEChallengeSolverHTTP01FluentImpl(ACMEChallengeSolverHTTP01 instance) {
    if (instance != null) {
      this.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
      this.withIngress(instance.getIngress());
    }
  }
  private ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder gatewayHTTPRoute;
  private ACMEChallengeSolverHTTP01IngressBuilder ingress;
  
  /**
   * This method has been deprecated, please use method buildGatewayHTTPRoute instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01GatewayHTTPRoute getGatewayHTTPRoute() {
    return this.gatewayHTTPRoute!=null ?this.gatewayHTTPRoute.build():null;
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRoute buildGatewayHTTPRoute() {
    return this.gatewayHTTPRoute!=null ?this.gatewayHTTPRoute.build():null;
  }
  public A withGatewayHTTPRoute(ACMEChallengeSolverHTTP01GatewayHTTPRoute gatewayHTTPRoute) {
    _visitables.get("gatewayHTTPRoute").remove(this.gatewayHTTPRoute);
    if (gatewayHTTPRoute!=null){ this.gatewayHTTPRoute= new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(gatewayHTTPRoute); _visitables.get("gatewayHTTPRoute").add(this.gatewayHTTPRoute);} else { this.gatewayHTTPRoute = null; _visitables.get("gatewayHTTPRoute").remove(this.gatewayHTTPRoute); } return (A) this;
  }
  public Boolean hasGatewayHTTPRoute() {
    return this.gatewayHTTPRoute != null;
  }
  public ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNested<A> withNewGatewayHTTPRoute() {
    return new ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNestedImpl();
  }
  public ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNested<A> withNewGatewayHTTPRouteLike(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
    return new ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNested<A> editGatewayHTTPRoute() {
    return withNewGatewayHTTPRouteLike(getGatewayHTTPRoute());
  }
  public ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNested<A> editOrNewGatewayHTTPRoute() {
    return withNewGatewayHTTPRouteLike(getGatewayHTTPRoute() != null ? getGatewayHTTPRoute(): new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder().build());
  }
  public ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNested<A> editOrNewGatewayHTTPRouteLike(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
    return withNewGatewayHTTPRouteLike(getGatewayHTTPRoute() != null ? getGatewayHTTPRoute(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01Ingress getIngress() {
    return this.ingress!=null ?this.ingress.build():null;
  }
  public ACMEChallengeSolverHTTP01Ingress buildIngress() {
    return this.ingress!=null ?this.ingress.build():null;
  }
  public A withIngress(ACMEChallengeSolverHTTP01Ingress ingress) {
    _visitables.get("ingress").remove(this.ingress);
    if (ingress!=null){ this.ingress= new ACMEChallengeSolverHTTP01IngressBuilder(ingress); _visitables.get("ingress").add(this.ingress);} else { this.ingress = null; _visitables.get("ingress").remove(this.ingress); } return (A) this;
  }
  public Boolean hasIngress() {
    return this.ingress != null;
  }
  public ACMEChallengeSolverHTTP01FluentImpl.IngressNested<A> withNewIngress() {
    return new ACMEChallengeSolverHTTP01FluentImpl.IngressNestedImpl();
  }
  public ACMEChallengeSolverHTTP01FluentImpl.IngressNested<A> withNewIngressLike(ACMEChallengeSolverHTTP01Ingress item) {
    return new ACMEChallengeSolverHTTP01FluentImpl.IngressNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01FluentImpl.IngressNested<A> editIngress() {
    return withNewIngressLike(getIngress());
  }
  public ACMEChallengeSolverHTTP01FluentImpl.IngressNested<A> editOrNewIngress() {
    return withNewIngressLike(getIngress() != null ? getIngress(): new ACMEChallengeSolverHTTP01IngressBuilder().build());
  }
  public ACMEChallengeSolverHTTP01FluentImpl.IngressNested<A> editOrNewIngressLike(ACMEChallengeSolverHTTP01Ingress item) {
    return withNewIngressLike(getIngress() != null ? getIngress(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01FluentImpl that = (ACMEChallengeSolverHTTP01FluentImpl) o;
    if (!java.util.Objects.equals(gatewayHTTPRoute, that.gatewayHTTPRoute)) return false;

    if (!java.util.Objects.equals(ingress, that.ingress)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(gatewayHTTPRoute,  ingress,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (gatewayHTTPRoute != null) { sb.append("gatewayHTTPRoute:"); sb.append(gatewayHTTPRoute + ","); }
    if (ingress != null) { sb.append("ingress:"); sb.append(ingress); }
    sb.append("}");
    return sb.toString();
  }
  class GatewayHTTPRouteNestedImpl<N> extends ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl<ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNested<N>> implements ACMEChallengeSolverHTTP01FluentImpl.GatewayHTTPRouteNested<N>,Nested<N>{
    GatewayHTTPRouteNestedImpl(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
      this.builder = new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(this, item);
    }
    GatewayHTTPRouteNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(this);
    }
    ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01FluentImpl.this.withGatewayHTTPRoute(builder.build());
    }
    public N endGatewayHTTPRoute() {
      return and();
    }
    
  }
  class IngressNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressFluentImpl<ACMEChallengeSolverHTTP01FluentImpl.IngressNested<N>> implements ACMEChallengeSolverHTTP01FluentImpl.IngressNested<N>,Nested<N>{
    IngressNestedImpl(ACMEChallengeSolverHTTP01Ingress item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressBuilder(this, item);
    }
    IngressNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01FluentImpl.this.withIngress(builder.build());
    }
    public N endIngress() {
      return and();
    }
    
  }
  
}
